src/newgrf_config.cpp
branchgamebalance
changeset 9895 7bd07f43b0e3
parent 6509 5978ce669c8e
child 9906 6f41b8713b65
--- a/src/newgrf_config.cpp	Mon Mar 19 09:33:17 2007 +0000
+++ b/src/newgrf_config.cpp	Mon Mar 19 12:38:16 2007 +0000
@@ -60,7 +60,7 @@
 bool FillGRFDetails(GRFConfig *config, bool is_static)
 {
 	if (!FioCheckFileExists(config->filename)) {
-		SETBIT(config->flags, GCF_NOT_FOUND);
+		config->status = GCS_NOT_FOUND;
 		return false;
 	}
 
@@ -210,14 +210,14 @@
 /** Check if all GRFs in the GRF config from a savegame can be loaded.
  * @return will return any of the following 3 values:<br>
  * <ul>
  * <li> GCF_ACTIVATED: No problems occured, all GRF files were found and loaded
  * <li> GCF_COMPATIBLE: For one or more GRF's no exact match was found, but a
  *     compatible GRF with the same grfid was found and used instead
  * <li> GCF_NOT_FOUND: For one or more GRF's no match was found at all
  * </ul> */
-GCF_Flags IsGoodGRFConfigList(void)
+GRFListCompatibility IsGoodGRFConfigList()
 {
-	GCF_Flags res = GCF_ACTIVATED;
+	GRFListCompatibility res = GLC_ALL_GOOD;
 
 	for (GRFConfig *c = _grfconfig; c != NULL; c = c->next) {
 		const GRFConfig *f = FindGRFConfig(c->grfid, c->md5sum);
@@ -233,7 +233,7 @@
 				SETBIT(c->flags, GCF_COMPATIBLE);
 
 				/* Non-found has precedence over compatibility load */
-				if (res != GCF_NOT_FOUND) res = GCF_COMPATIBLE;
+				if (res != GLC_NOT_FOUND) res = GLC_COMPATIBLE;
 				goto compatible_grf;
 			}
 
@@ -241,8 +241,8 @@
 			md5sumToString(buf, lastof(buf), c->md5sum);
 			DEBUG(grf, 0, "NewGRF %08X (%s) not found; checksum %s", BSWAP32(c->grfid), c->filename, buf);
 
-			SETBIT(c->flags, GCF_NOT_FOUND);
-			res = GCF_NOT_FOUND;
+			c->status = GCS_NOT_FOUND;
+			res = GLC_NOT_FOUND;
 		} else {
 compatible_grf:
 			DEBUG(grf, 1, "Loading GRF %08X from %s", BSWAP32(f->grfid), f->filename);
@@ -335,7 +335,7 @@
 
 
 /* Scan for all NewGRFs */
-void ScanNewGRFFiles(void)
+void ScanNewGRFFiles()
 {
 	uint num;
 
@@ -364,7 +364,6 @@
 #ifdef ENABLE_NETWORK
 
 /** Structure for UnknownGRFs; this is a lightweight variant of GRFConfig */
-typedef struct UnknownGRF UnknownGRF;
 struct UnknownGRF : public GRFIdentifier {
 	UnknownGRF *next;
 	char   name[NETWORK_GRF_NAME_LENGTH];
@@ -452,7 +451,7 @@
 };
 
 
-static void Save_NGRF(void)
+static void Save_NGRF()
 {
 	int index = 0;
 
@@ -464,7 +463,7 @@
 }
 
 
-static void Load_NGRF(void)
+static void Load_NGRF()
 {
 	ClearGRFConfigList(&_grfconfig);
 	while (SlIterateArray() != -1) {
@@ -210,14 +210,14 @@
  * @return will return any of the following 3 values:<br>
  * <ul>
- * <li> GCF_ACTIVATED: No problems occured, all GRF files were found and loaded
- * <li> GCF_COMPATIBLE: For one or more GRF's no exact match was found, but a
+ * <li> GLC_ALL_GOOD: No problems occured, all GRF files were found and loaded
+ * <li> GLC_COMPATIBLE: For one or more GRF's no exact match was found, but a
  *     compatible GRF with the same grfid was found and used instead
@@ -210,14 +210,14 @@
  *     compatible GRF with the same grfid was found and used instead
- * <li> GCF_NOT_FOUND: For one or more GRF's no match was found at all
+ * <li> GLC_NOT_FOUND: For one or more GRF's no match was found at all
  * </ul> */